This is a core package for qb app

qb app is a complete application that implements simple architectural concepts. Its goal to separate business logic from infrastructure. 

Core modules will contain only logic/code that captures business concepts.

Infrastructure modules will implement infrastructure specific code.

In this version, all core modules will be in a single package. Future versions will split core modules in a more granular scope to help implementers focus on specific modules

see documentation/packaging_concepts.md